CREATE TABLE types (
	id SERIAL NOT NULL,
	name TEXT NOT NULL DEFAULT ''
);
CREATE UNIQUE INDEX "types_id" on "types" using btree ( "id" );
REVOKE ALL on "types" from PUBLIC;
GRANT  ALL on "types" to "www-data";
GRANT  ALL on "types" to "joey";
REVOKE ALL on "types_id_seq" from PUBLIC;
GRANT  ALL on "types_id_seq" to "www-data";
GRANT  ALL on "types_id_seq" to "joey";


CREATE TABLE organisation (
	id SERIAL NOT NULL,
	name TEXT NOT NULL DEFAULT '',
	address TEXT NOT NULL DEFAULT '',
	email TEXT NOT NULL DEFAULT '',
	phone TEXT NOT NULL DEFAULT '',
	comment TEXT NOT NULL DEFAULT ''
);
CREATE UNIQUE INDEX "organisation_id" on "organisation" using btree ( "id" );
CREATE INDEX "organisation_name" on "organisation" using btree ( "name" );
REVOKE ALL on "organisation" from PUBLIC;
GRANT  ALL on "organisation" to "www-data";
GRANT  ALL on "organisation" to "joey";
REVOKE ALL on "organisation_id_seq" from PUBLIC;
GRANT  ALL on "organisation_id_seq" to "www-data";
GRANT  ALL on "organisation_id_seq" to "joey";


CREATE TABLE component (
	id SERIAL NOT NULL,
	serno TEXT NOT NULL DEFAULT '',
	name TEXT NOT NULL DEFAULT '',
	price NUMERIC(10,2),
	owner INT4 NOT NULL references organisation(id) on delete cascade,
	hwtype INT4 NOT NULL references types(id) on delete cascade,
	starttime timestamp with time zone DEFAULT '1980-01-01 00:00:00+01'::timestamp with time zone NOT NULL,
	endtime timestamp with time zone DEFAULT NULL,
	status CHAR(10) NOT NULL DEFAULT 'in use',
	comment TEXT NOT NULL DEFAULT ''
);
CREATE UNIQUE INDEX "component_id" on "component" using btree ( "id" );
CREATE INDEX "component_serno" on "component" using btree ( "serno" );
CREATE INDEX "component_name" on "component" using btree ( "name" );
REVOKE ALL on "component" from PUBLIC;
GRANT  ALL on "component" to "www-data";
GRANT  ALL on "component" to "joey";
REVOKE ALL on "component_id_seq" from PUBLIC;
GRANT  ALL on "component_id_seq" to "www-data";
GRANT  ALL on "component_id_seq" to "joey";


CREATE TABLE compound (
	id SERIAL NOT NULL,
	name TEXT NOT NULL DEFAULT '',
	hostname TEXT NOT NULL DEFAULT '',
	ip TEXT NOT NULL DEFAULT '',
	ident TEXT NOT NULL DEFAULT '',
	location INT4 NOT NULL references organisation(id) on delete cascade,
	status CHAR(10) NOT NULL DEFAULT 'in use',
	comment TEXT NOT NULL DEFAULT ''
);
CREATE UNIQUE INDEX "compound_id" on "compound" using btree ( "id" );
CREATE UNIQUE INDEX "compound_name" on "compound" using btree ( "name" );
REVOKE ALL on "compound" from PUBLIC;
GRANT  ALL on "compound" to "www-data";
GRANT  ALL on "compound" to "joey";
REVOKE ALL on "compound_id_seq" from PUBLIC;
GRANT  ALL on "compound_id_seq" to "www-data";
GRANT  ALL on "compound_id_seq" to "joey";


CREATE TABLE screw (
	component INT4 NOT NULL references component(id) on delete cascade,
	compound  INT4 NOT NULL references compound(id) on delete cascade,
	usage TEXT NOT NULL DEFAULT '',
	starttime timestamp with time zone DEFAULT '1980-01-01 00:00:00+01'::timestamp with time zone NOT NULL,
	endtime timestamp with time zone DEFAULT NULL
);
CREATE INDEX "screw_component" on "screw" using btree ( "component" );
CREATE INDEX "screw_compound" on "screw" using btree ( "compound" );
REVOKE ALL on "screw" from PUBLIC;
GRANT  ALL on "screw" to "www-data";
GRANT  ALL on "screw" to "joey";
